@@ -186,11 +186,11 @@ class I2AChatApiClient:
 
     def send_system_message(self, chat_room_identifier, message):
         """
-       Queuing system message to be saved and send on websocket in provided chat room
-       :param chat_room_identifier: str
-       :param message
-       :return: response (str)
-       """
+        Queuing system message to be saved and send on websocket in provided chat room
+        :param chat_room_identifier: str
+        :param message
+        :return: response (str)
+        """
         url = self._get_full_url(f'system-message/send-system-message/')
         data = {
             'chat_room_identifier': chat_room_identifier,
@@ -203,5 +203,33 @@ class I2AChatApiClient:
             raise I2AChatApiClientUnauthorizedException(data=response.json())
         elif response.status_code == 404:
             raise I2AChatApiClientNotFoundError(data=response.json())
+        elif response.status_code == 400:
+            raise I2AChatApiClientValidationError(data=response.json())
+        else:
+            raise Exception(f'Send system message failed. {self._status_code_message(response)}')
+
+    def report_chat_message(self, application_user_identifier, message_timestamp_identifier, message=None):
+        """
+        Queuing system message to be saved and send on websocket in provided chat room
+        :param application_user_identifier: str
+        :param message_timestamp_identifier: str
+        :param message: str
+        :return: response - identifier (str)
+       """
+        url = self._get_full_url(f'reported-chat-message/')
+        data = {
+            'application_user_identifier': application_user_identifier,
+            'message_timestamp_identifier': message_timestamp_identifier,
+            'message': message
+        }
+        response = requests.post(url, data, headers=self._required_headers())
+        if response.status_code == 200:
+            return response
+        elif response.status_code == 401:
+            raise I2AChatApiClientUnauthorizedException(data=response.json())
+        elif response.status_code == 404:
+            raise I2AChatApiClientNotFoundError(data=response.json())
+        elif response.status_code == 400:
+            raise I2AChatApiClientValidationError(data=response.json())
         else:
             raise Exception(f'Send system message failed. {self._status_code_message(response)}')
